
## Preguntas

### Documentacion
- Revisar todos los nombres

### Data
- En show dataset y bag, ver si cambiar mode compact to mode csv

### Datasets

### Classifiers

### Report
- Hamming score as metric

### Tutorials
- Ejecutarlos todos de nuevo
- Que se entienda mejor, mas prints y tal.

### Otros
- documentacion bonita del codigo a web. Usar sphinx
- Pequeño experimento
- mostrar graficos por metrica, subset accuracy con 4 barras de cada clasificador
- comentarios de python
- funcion para guardar mimldataset to csv o arff
- splits test